@@ -28,10 +28,11 @@ def config_txt_string(targ):
 def builder():
     BASE_USER = os.path.expanduser('~')
 
-    if os.name == 'nt': # windows
-        PIO = PLATFORMIO = os.path.join(BASE_USER,'.platformio','penv','Scripts','platformio.exe')
-    elif os.name == 'posix': # linux
-        PIO = PLATFORMIO = os.path.join(BASE_USER,'.platformio','penv','bin','pio')
+    # if os.name == 'nt': # windows
+    #     PIO = PLATFORMIO = os.path.join(BASE_USER,'.platformio','penv','Scripts','platformio.exe')
+    # elif os.name == 'posix': # linux
+    #     PIO = PLATFORMIO = os.path.join(BASE_USER,'.platformio','penv','bin','pio')
+    PIO = 'pio'
 
     run_cmd = lambda cmd: subprocess.run(cmd, stdout=sys.stdout, stderr=sys.stderr, shell=True)
 
@@ -100,8 +101,7 @@ def builder():
             shutil.copy(SRC_PATH, DST_PATH)
 
             # build filesystem image
-            #build_spiffs_cmd = f"%s run --target buildfs --environment %s -d firmware" % (PIO,BOARD)
-            build_spiffs_cmd = f"pio run --target buildfs --environment %s -d firmware" % (BOARD)
+            build_spiffs_cmd = f"%s run --target buildfs --environment %s -d firmware" % (PIO,BOARD)
             #handle_verbose(run_cmd(build_spiffs_cmd)) # -s to silent
             run_cmd(build_spiffs_cmd) # -s to silent
             print()
@@ -114,8 +114,7 @@ def builder():
         else: print(f'No %s.txt sensor configuration file found.\n' % targ[0])
 
     # build sketch image
-    # build_sketch_cmd = "%s run -d firmware" % PIO
-    build_sketch_cmd = "pio run -d firmware"
+    build_sketch_cmd = "%s run -d firmware" % PIO
     #handle_verbose(run_cmd(build_sketch_cmd)) # -s to silent
     run_cmd(build_sketch_cmd) # -s to silent
     print()
